# Libraries ---------------------------------------------------------------

library(countrycode)
library(lfe)
library(texreg)
library(dplyr)
library(readr)
library(texreg)
library(readxl)
library(MatchIt)
library(xtable)
library(AER)
library(ivpack)
library(lmtest)
library(foreign)
library(tidyverse)
library(ggrepel)
library(ebal)
library(lubridate)
library(gridExtra)


# Load data ---------------------------------------------------------------

load("./data/diss_df.rda")


# Section 3: Summary Statistics and Descriptive Evidence ------------------


# * Section 3.2 ----------------------------------------------------


# ** Figure 1 --------------------------------------------------------------


# left panel 

plot3_aidps <- ggplot(diss_df, 
                      aes(x = factor(cabinetINC), 
                          y = aiddata_AidGDP_ln)) +
  geom_boxplot() +
  theme_bw() +
  labs(x = "Power-Sharing Cabinet \n(1 = Yes, 0 = No)", 
       y = "Aid/GDP (log)")


# right panel 

# Labels for easier plotting
diss_df$cabinetINClabel <- ifelse(diss_df$cabinetINC == 1, "Power-Sharing", 
                                  "No \nPower-Sharing Cabinet")

# generate scatterplot, divided by power-sharing
plot4_psaid_democ <- ggplot(diss_df, aes(x = log(aiddata_AidGDP), 
                                         y = polity2_t2))  +
  geom_point(size = 1.7, alpha = 0.5) +
  geom_smooth(method = "lm") +
  # geom_rug() +
  theme_bw() +
  labs(x = "Aid / GDP \n(log)", y = "Polity score at t2 ") +
  facet_wrap( ~ cabinetINClabel) 


ggsave(grid.arrange(plot3_aidps,
                    plot4_psaid_democ,
                    nrow = 1), 
       file = "./plots/appendix_figure_1.pdf", 
       width = 8, 
       height = 3.5, 
       units = "in")

# * Section 3.3 -------------------------------------------------------------


# ** Figure 2 --------------------------------------------------------------

load("./data/nelda_ps.rda")

plot_aidcutoff <- ggplot(nelda_ps%>% 
                           mutate(cutoff = ifelse(nelda57 == 1, "Aid Cut-Off Threatened", "No Aid Cut-Off Threatened")), 
                         aes(x = cutoff, 
                             y = aid_ln)) +
  geom_jitter(width = 0.3, size = 2, alpha = 0.5) +
  stat_summary(fun.y = mean, fun.ymin = mean, fun.ymax = mean,
               geom = "crossbar", width = 0.5) +  
  theme_bw() +
  labs(x = "", y = "Aid/GDP (log)")


ggsave(plot_aidcutoff, 
       file = "./plots/appendix_figure_2.pdf", 
       width = 4, 
       height = 4, 
       units = "in")


# Section 4: Endogeneity --------------------------------------------------

# Matching  ---------------------------------------------------------------

# * Matching: Democ scores ------------------------------------------------

# load data
load("./data/diss_df.rda")

# select relevant variables
match_democ_data <- diss_df %>% 
  ungroup() %>% 
  dplyr::select(cabinetINC, cabinetCOUNT, seniorINC,
                seniorCOUNT, nonseniorINC, nonseniorCOUNT,
                aiddata_AidGDP, population, nonstate,
                WBnatres, fh, GDP_per_capita, conf_intens,
                aiddata_AidGDP_ln, year,
                GWNo, year, 
                polity_chng, polity2, polity2_t2, # check 
                fh, fh_chng, fh_t2,
                pc_period, Location, ln_pop, ln_gdp_pc)

# keep only complete cases (necessary for matching)
match_democ_data <- match_democ_data[complete.cases(match_democ_data), ]

# generate pretreatment controls: control variables in first post-conflict year
match_democ_data <- match_democ_data %>% 
  arrange(GWNo, pc_period, year) %>% 
  group_by(GWNo, pc_period) %>% 
  mutate(match_aiddata_AidGDP_ln = first(aiddata_AidGDP_ln),
         match_pop = first(population),
         match_gdp = first(GDP_per_capita),
         match_nonstate = first(nonstate),
         match_WBnatres = first(WBnatres),
         match_polity = first(polity2), 
         match_fh = first(fh))

# explicitly convert to data frame
match_democ_data <- as.data.frame(match_democ_data)

# Perform matching algorithm 
set.seed(123)
match_democ_res <- matchit(cabinetINC ~
                             match_aiddata_AidGDP_ln +
                             log(match_gdp) +
                             log(match_pop) +
                             conf_intens + # conf_intens is already pre-treatment
                             match_nonstate +
                             log(match_WBnatres + 1)  +
                             match_polity,
                           method = "nearest",
                           distance = "mahalanobis",
                           ratio = 2,
                           data = match_democ_data)

# extract data
match_democ_df <- match.data(match_democ_res)

## Reestimate Model
model_matched_democ <- felm(polity2_t2 ~  
                              cabinetINC *
                              aiddata_AidGDP_ln +
                              log(GDP_per_capita) +
                              log(population) +
                              conf_intens +
                              nonstate +
                              WBnatres +
                              polity2
                            | 0 | 0 | Location 
                            ,
                            data=match_democ_df)



# * Matching: Elections -----------------------------------------------------

# load data
load("./data/nelda_ps.rda")

# Create matched data set for elections

# First: create values for matching at the beginning of post-conflict period
# to approximate pre-treatment values of the covariates

nelda_ps_matching <- nelda_ps %>% 
  ungroup() %>% 
  arrange(country, year) %>% 
  group_by(country, pc_period) %>% 
  mutate(matchyear = first(year)) %>%
  mutate(match_natres = first(WBnatres),
         match_aiddata_AidGDP = first(aiddata_AidGDP),
         match_pop = first(population),
         match_conf_intens = first(conf_intens),
         match_nonstate = first(nonstate),
         match_fh = first(fh),
         match_nelda45 = first(nelda45),
         match_gdp_per_capita_un = first(gdp_per_capita_un)) 

# select only relevant variables
match_data_elections <- nelda_ps_matching %>% 
  dplyr::select(cabinetINC.12, 
                aiddata_AidGDP, 
                gdp_per_capita_un, 
                year, 
                country,
                seniorINC.12, 
                nonseniorINC.12, 
                seniorCOUNT.12, 
                nonseniorCOUNT.12,
                cabinetCOUNT.12, 
                population, conf_intens, nonstate, WBnatres, fh, nelda45,
                quality, v2xel_frefair, electionid, 
                iso2c, aiddata_Aid, GDP,
                match_natres, match_aiddata_AidGDP, match_pop, match_conf_intens,
                match_nonstate, match_fh, match_nelda45, match_gdp_per_capita_un)
match_data_elections <- match_data_elections[complete.cases(match_data_elections), ]
match_data_elections <- as.data.frame(match_data_elections)


# Perform Matching
match_data_elections <- match_data_elections %>% 
  arrange(country, pc_period, year)

set.seed(1234)

match_res <- matchit(cabinetINC.12 ~ 
                       log(match_aiddata_AidGDP) + 
                       log(match_gdp_per_capita_un) + 
                       log(match_pop) + 
                       match_conf_intens + 
                       log(match_natres + 1)  + 
                       match_nonstate +
                       match_fh , 
                     data = match_data_elections, 
                     method = "nearest",
                     ratio = 2,
                     distance = "mahalanobis")

match_df_elec_reg <- match.data(match_res)

# reestimate on matched sample
match_df_elec_reg$aid_ln <- log(match_df_elec_reg$aiddata_AidGDP)

# cabinetINC * Aid & NELDA
model_matched_elections <- felm(v2xel_frefair ~ 
                                  cabinetINC.12 *
                                  aid_ln +
                                  log(gdp_per_capita_un) +
                                  log(population) +
                                  conf_intens +
                                  WBnatres +
                                  fh
                                | 0 | 0 | country, 
                                data = match_df_elec_reg )



# * Matching: Rule of Law ---------------------------------------------------


# prepare data without missings
match_ji_data <- diss_df %>% 
  ungroup() %>% 
  dplyr::select(cabinetINC, cabinetCOUNT, seniorINC,
                seniorCOUNT, nonseniorINC, nonseniorCOUNT,
                aiddata_AidGDP, population, nonstate,
                WBnatres, fh, GDP_per_capita, conf_intens,
                aiddata_AidGDP_ln, LJI_t2, v2x_jucon_t2, GWNo, year, 
                pc_period, Location, ln_pop, ln_gdp_pc,
                LJI_regional_mean, commonlaw, duration_constitution, Ethnic, polity_chng)
match_ji_data <- match_ji_data[complete.cases(match_ji_data), ]

# generate pretreatment controls
match_ji_data <- match_ji_data %>% 
  arrange(GWNo, pc_period, year) %>% 
  group_by(GWNo, pc_period) %>% 
  mutate(match_aiddata_AidGDP_ln = first(aiddata_AidGDP_ln),
         match_pop = first(population),
         match_gdp = first(GDP_per_capita),
         match_nonstate = first(nonstate),
         match_WBnatres = first(WBnatres),
         match_fh = first(fh), 
         match_duration_constitution = first(duration_constitution),
         match_LJI_regional_mean = first(LJI_regional_mean))



match_ji_data <- as.data.frame(match_ji_data)

match_ji_res <- matchit(cabinetINC ~
                          match_aiddata_AidGDP_ln +
                          log(match_gdp) +
                          log(match_pop) +
                          conf_intens + # conf_intens is already pre-treatment
                          match_nonstate +
                          log(match_WBnatres + 1)  +
                          match_fh ,
                        method = "nearest",
                        ratio = 2, 
                        distance = "mahalanobis",
                        data = match_ji_data)

# extract data
match_ji_res_df <- match.data(match_ji_res)

model_matched_rol <- felm(LJI_t2 ~ 
                            cabinetINC *
                            aiddata_AidGDP_ln +
                            ln_gdp_pc +
                            ln_pop +
                            conf_intens +
                            nonstate +
                            WBnatres +
                            fh
                          | 0 | 0 | GWNo
                          ,
                          data=match_ji_res_df )


# * Matching: Public Goods --------------------------------------------------

# prepare data without missings
match_spending_data <- diss_df %>% 
  ungroup() %>% 
  dplyr::select(cabinetINC, cabinetCOUNT, seniorINC,
                seniorCOUNT, nonseniorINC, nonseniorCOUNT,
                aiddata_AidGDP, population, nonstate,
                WBnatres, fh, GDP_per_capita, conf_intens,
                aiddata_AidGDP_ln, 
                #      LJI_t2_logit, v2x_jucon_t2_logit, 
                GWNo, year, region,
                pc_period, Location, ln_pop, ln_gdp_pc, 
                v2dlencmps_t1,v2x_corr,
                polity_chng)
match_spending_data <- match_spending_data[complete.cases(match_spending_data), ]

# generate pretreatment controls, i.e. measured at the beginning of the
# post-conflict period

match_spending_data <- match_spending_data %>% 
  arrange(GWNo, pc_period, year) %>% 
  group_by(GWNo, pc_period) %>% 
  mutate(match_aiddata_AidGDP_ln = first(aiddata_AidGDP_ln),
         match_pop = first(population),
         match_gdp = first(GDP_per_capita),
         match_nonstate = first(nonstate),
         match_WBnatres = first(WBnatres),
         match_fh = first(fh))



match_spending_data <- as.data.frame(match_spending_data)

match_spending_res <- matchit(cabinetINC ~
                                match_aiddata_AidGDP_ln +
                                log(match_gdp) +
                                log(match_pop) +
                                conf_intens + # conf_intens is already pre-treatment
                                match_nonstate +
                                log(match_WBnatres + 1)  +
                                match_fh ,
                              method = "nearest",
                              ratio = 2,
                              distance = "mahalanobis",
                              data = match_spending_data)

# extract data
match_spending_res_df <- match.data(match_spending_res)


# output
model_matched_pubgoods <- felm(v2dlencmps_t1 ~  
                                 cabinetINC *
                                 aiddata_AidGDP_ln +
                                 log(GDP_per_capita) +
                                 log(population) +
                                 conf_intens +
                                 nonstate + 
                                 WBnatres + 
                                 fh
                               | 0 | 0 | GWNo
                               ,
                               data=match_spending_res_df)


# 2SLS / IV ---------------------------------------------------------------

# * 2SLS: Democracy ---------------------------------------------------------------

# load data with instrument; this gives "instrument_df" data frame
load(file = "./data/instrumentedAid2.RData")
load("./data/diss_df.rda")

diss_df_iv <- merge(diss_df, 
                    instrument_df, 
                    by = c("iso2c", "year"), all.x = TRUE)


# subset only complete.cases / necessary for cluster.robust.se()
iv_na <- na.omit(diss_df_iv[, c("polity_chng", 
                                "cabinetCOUNT", 
                                "cabinetINC", 
                                "aiddata_Aid",
                                "aiddata_AidGDP_ln",
                                "aiddata_AidPC_ln",
                                "GDP_per_capita", 
                                "population", 
                                "conf_intens", 
                                "WBnatres", 
                                "polity2", 
                                "polity2_t2",
                                "total_sum_except", 
                                "year", 
                                "GWNo", 
                                "GDP",
                                "nonstate")])

# to proceed with IV estimation I first hard-code the instrument
iv_na$instr_aid_gdp_ln <- log(iv_na$total_sum_except / iv_na$GDP)

# data transformation for Stata
iv_na$ln_gdp_pc <- log(iv_na$GDP_per_capita)
iv_na$ln_pop <- log(iv_na$population)

# and save data to Stata format

iv_na$cabinetINCxaid_ln <- iv_na$cabinetINC * iv_na$aiddata_AidGDP_ln
iv_na$cabinetINCxaid_ln_instr <- iv_na$cabinetINC * iv_na$instr_aid_gdp_ln

# We need this to run Stata for the K-P Statistic
foreign::write.dta(iv_na, "./data/output/iv_na_democ.dta")


# IV for Polity
democ_pchng_iv <- lfe::felm(polity2_t2 ~ 
                              cabinetINC + 
                              log(GDP_per_capita) +
                              log(population) +
                              nonstate +
                              conf_intens +
                              WBnatres +
                              polity2 
                            | year | (cabinetINCxaid_ln|aiddata_AidGDP_ln ~ 
                                        cabinetINCxaid_ln_instr + instr_aid_gdp_ln) | GWNo,
                            data = iv_na)

countries_democ_iv <- length(unique(iv_na$GWNo))

# * 2SLS: Elections ---------------------------------------------------------


# Load elections data
load("./data/nelda_ps.rda")

# load instrument data for aid
load(file = "./data/instrumentedAid2.RData")

nelda_ivreg <- left_join(nelda_ps, instrument_df,
                         by = c("year", "iso2c"))

nelda_ivreg$total_sum_except <- as.numeric(nelda_ivreg$total_sum_except)

nelda_ivreg$instr_aid_gdp <- log(nelda_ivreg$total_sum_except / nelda_ivreg$GDP)

nelda_ivreg$date <- NULL
nelda_ivreg$StartDate2 <- NULL
nelda_ivreg$yearmon.x <- NULL
nelda_ivreg$yearmon.y <- NULL
nelda_ivreg[nelda_ivreg == ""] <- NA

nelda_ivreg$ln_gdp_pc <- log(nelda_ivreg$gdp_per_capita_un)
nelda_ivreg$ln_pop <- log(nelda_ivreg$population)

# hard code interactions for felm
nelda_ivreg$cabXaid_instr <- nelda_ivreg$cabinetINC.12 * nelda_ivreg$instr_aid_gdp
nelda_ivreg$cabXaid <- nelda_ivreg$cabinetINC.12 * nelda_ivreg$aid_ln



# V-Dem
model_iv_aidps_vdem <- felm(v2xel_frefair  ~ 
                              cabinetINC.12  + 
                              WBnatres + 
                              fh + 
                              nonstate + 
                              conf_intens + 
                              ln_gdp_pc + 
                              ln_pop 
                            |year | (cabXaid  | aid_ln ~cabXaid_instr  + instr_aid_gdp ) | country, 
                            data = nelda_ivreg)


names(nelda_ivreg) <- gsub("\\.", "_", names(nelda_ivreg))
nelda_ivreg <- nelda_ivreg %>% 
  dplyr::select(-starts_with("nelda"))
haven::write_dta(nelda_ivreg, "./data/output/nelda_ivreg.dta")


countries_elec_iv <- length(unique(nelda_ivreg$country))


# * 2SLS: Rule of Law -------------------------------------------------------



# ivreg with Jud Ind

library(AER)
library(ivpack)
library(lmtest)

# load instrument
load(file = "./data/instrumentedAid2.RData")
load("./data/diss_df.rda")

diss_df <- merge(diss_df, instrument_df, by = c("year", "iso2c"), all.x = TRUE)
diss_df$total_sum_except <- as.numeric(diss_df$total_sum_except)


# subset only complete.cases / necessary for cluster.robust.se()
iv_na <- na.omit(diss_df[, c(
  "cabinetCOUNT", 
  "cabinetINC", 
  "aiddata_Aid",
  "aiddata_AidGDP_ln",
  "aiddata_AidPC_ln",
  "fh",
  "GDP_per_capita", 
  "population", 
  "conf_intens", 
  "WBnatres", 
  "total_sum_except", 
  "year", 
  "GWNo", 
  "GDP",
  "nonstate", 
  "LJI_t2", 
  "v2x_jucon_t2")])



iv_na$aid_instrumented_gdp_ln <- log(iv_na$total_sum_except / iv_na$GDP)
diss_df$aid_instrumented_gdp_ln <- log(diss_df$total_sum_except / diss_df$GDP)

# to proceed with IV estimation I first hard-code the instrument
iv_na$instr_aid_gdp_ln <- log(iv_na$total_sum_except / iv_na$GDP)

# data transformation for Stata
iv_na$ln_gdp_pc <- log(iv_na$GDP_per_capita)
iv_na$ln_pop <- log(iv_na$population)

# stuff for stata
# diss_df$region_num <- as.numeric(as.factor(diss_df$region))
# diss_df$country_year_num <- as.numeric(as.factor(diss_df$country_year))

# hard code interaction variable
iv_na$cabincXaid <- iv_na$aiddata_AidGDP_ln * iv_na$cabinetINC
iv_na$cabincXaid_instr <- iv_na$aid_instrumented_gdp_ln * iv_na$cabinetINC

foreign::write.dta(iv_na, "./data/output/iv_na_rol.dta")

model_iv_judind_lji <- felm(LJI_t2 ~ 
                              cabinetINC +
                              ln_gdp_pc +
                              ln_pop +
                              nonstate +
                              conf_intens +
                              WBnatres +
                              fh 
                            | year | (aiddata_AidGDP_ln|cabincXaid ~ aid_instrumented_gdp_ln + cabincXaid_instr) | GWNo, 
                            data = iv_na)

countries_rol_iv <- length(unique(iv_na$GWNo))

# * 2SLS: Public Goods ------------------------------------------------------


# load data with instrument; this gives "instrument_df" data frame
load(file = "./data/diss_df.rda")
load(file = "./data/instrumentedAid2.RData")

diss_df_iv <- merge(diss_df, 
                    instrument_df, 
                    by = c("iso2c", "year"), all.x = TRUE)


# subset only complete.cases / necessary for cluster.robust.se()
iv_na <- na.omit(diss_df_iv[, c("cabinetCOUNT", 
                                "cabinetINC", 
                                "aiddata_Aid",
                                "aiddata_AidGDP_ln",
                                
                                "fh",
                                "GDP_per_capita", 
                                "population", 
                                "conf_intens", 
                                "WBnatres", 
                                "total_sum_except", 
                                "year", 
                                "GWNo", 
                                "GDP",
                                "nonstate", 
                                "v2dlencmps_t1", 
                                "v2x_corr_t1")])


# to proceed with IV estimation I first hard-code the instrument
iv_na$aid_instrumented_gdp_ln <- log(iv_na$total_sum_except / iv_na$GDP)

# to proceed with IV estimation I first hard-code the instrument
iv_na$instr_aid_gdp_ln <- log(iv_na$total_sum_except / iv_na$GDP)

# data transformation for Stata
iv_na$ln_gdp_pc <- log(iv_na$GDP_per_capita)
iv_na$ln_pop <- log(iv_na$population)


# hard code interaction variable
iv_na$cabincXaid <- iv_na$aiddata_AidGDP_ln * iv_na$cabinetINC
iv_na$cabincXaid_instr <- iv_na$aid_instrumented_gdp_ln * iv_na$cabinetINC

# stuff for stata
# diss_df$region_num <- as.numeric(as.factor(diss_df$region))
# diss_df$country_year_num <- as.numeric(as.factor(diss_df$country_year))
foreign::write.dta(iv_na, "./data/output/iv_na_pubgoods.dta")


library(lfe)
iv_spending <- felm(v2dlencmps_t1 ~ 
                      cabinetINC +  # outcome equation / 2nd stage regression

                      ln_gdp_pc +
                      ln_pop +
                      conf_intens +
                      nonstate +
                      WBnatres +
                      fh 
                    | year | (aiddata_AidGDP_ln|cabincXaid ~ aid_instrumented_gdp_ln + cabincXaid_instr) | GWNo, 
                    data = iv_na)

countries_pubgoods_iv <- length(unique(iv_na$GWNo))



# * Save Table 3 ----------------------------------------------------------



library(texreg)
model_list <- list(democ_pchng_iv,
                   model_matched_democ,
                   model_iv_aidps_vdem,
                   model_matched_elections, 
                   model_iv_judind_lji, 
                   model_matched_rol,
                   iv_spending, 
                   model_matched_pubgoods)

coef_name_map <- list(
  # PS vars
  cabinetINC = "Power-Sharing (binary)",
  cabinetINC.12 = "Power-Sharing (binary)",
  cabinetCOUNT = "Power-Sharing (No. of seats)", 
  cabinetCOUNT.12 = "Power-Sharing (No. of seats)",
  
  # aid vars
  dga_gdp_zero = "DGA/GDP (log)", 
  program_aid_gdp_zero = "Program Aid/GDP (log)", 
  commodity_aid_gdp_zero = "Budget Aid/GDP (log)", 
  "`aiddata_AidGDP_ln(fit)`" = "Aid / GDP (instrumented)",
  "`aid_ln(fit)`" = "Aid / GDP (instrumented)",
  aiddata_AidGDP_ln = "Aid / GDP (log)",
  aid_ln = "Aid / GDP (log)",
  
  # interaction terms
  "`cabincXaid(fit)`" = "Power-Sharing (binary) * Aid (instrumented)",
  "`cabXaid(fit)`" = "Power-Sharing (binary) * Aid (instrumented)",
  "`cabinetINCxaid_ln(fit)`" = "Power-Sharing (binary) * Aid (instrumented)",
  "cabinetINC.12:aid_ln" = "Power-Sharing (binary) * Aid",
  "cabinetINC * aiddata_AidGDP_ln" = "Power-Sharing (binary) * Aid",
  "cabinetINC:aiddata_AidGDP_ln" = "Power-Sharing (binary) * Aid")

htmlreg(model_list, 
        stars = c(0.01, 0.05, 0.1),
        custom.coef.map = coef_name_map, 
        file = "./tables/appendix_table_3.html", 
        include.lr = F, 
        table = F,
        use.packages = F,
        include.rsquared = F, 
        include.variance = F)



# Section 4.2: Matching Diagnostics ---------------------------------------


# Load data 
load("./data/diss_df.rda")

# select relevant variables
match_democ_data <- diss_df %>% 
  ungroup() %>% 
  dplyr::select(cabinetINC, cabinetCOUNT, seniorINC,
                seniorCOUNT, nonseniorINC, nonseniorCOUNT,
                aiddata_AidGDP, population, nonstate,
                WBnatres, fh, GDP_per_capita, conf_intens,
                aiddata_AidGDP_ln, 
                GWNo, year, 
                polity2, polity2_t2, # check 
                fh, fh_t2, 
                pc_period, Location, ln_pop, ln_gdp_pc)

# keep only complete cases (necessary for matching)
match_democ_data <- match_democ_data[complete.cases(match_democ_data), ]

# generate pretreatment controls: control variables in first post-conflict year
match_democ_data <- match_democ_data %>% 
  arrange(GWNo, pc_period, year) %>% 
  group_by(GWNo, pc_period) %>% 
  mutate(match_aiddata_AidGDP_ln = first(aiddata_AidGDP_ln),
         match_pop = first(population),
         match_gdp = first(GDP_per_capita),
         match_nonstate = first(nonstate),
         match_WBnatres = first(WBnatres),
         match_polity = first(polity2), 
         match_fh = first(fh))

# explicitly convert to data frame
match_democ_data <- as.data.frame(match_democ_data)

# * Diagnostics: Perform matching algorithm ------------------------------------------

set.seed(123)
match_democ_res <- matchit(cabinetINC ~
                             match_aiddata_AidGDP_ln +
                             log(match_gdp) +
                             log(match_pop) +
                             conf_intens + # conf_intens is already pre-treatment
                             match_nonstate +
                             log(match_WBnatres + 1)  +
                             match_polity,
                           method = "nearest",
                           distance = "mahalanobis",
                           ratio = 2,
                           data = match_democ_data)

# extract data
match_democ_df <- match.data(match_democ_res)

# * Diagnostics: Balance Improvement Plot ------------------------------------------------

balance_improvement <- summary(match_democ_res)$reduction
row.names(balance_improvement) <- c("Aid / GDP (log)", 
                                    "GDP / PC (log)",
                                    "Population (log)", 
                                    "Conflict Intensity",
                                    "Nonstate Conflict",
                                    "Nat. Res. Rents (log)", 
                                    "Regime Type (Polity)")

balance_improvement <- data.frame(variable = row.names(balance_improvement), 
                                  percent_balance_improvement = round(balance_improvement[, 1], 2))


plot_balanceimpr <- data.frame(`All Data` = abs(summary(match_democ_res, 
                                                        standardize = T)$sum.all$`Std. Mean Diff.`), 
                               `Matched Data` = abs(summary(match_democ_res, 
                                                            standardize = T)$sum.matched$`Std. Mean Diff.`),
                               cov = balance_improvement$variable) %>% 
  gather(key, value, -cov) %>% 
  filter(!is.nan(value) & !is.infinite(value)) %>% 
  mutate(key = gsub("\\.", " ", key))

# Plot balance improvement
plot_balanceimpr_out <- plot_balanceimpr %>% 
  ggplot(., aes(x = key, y = value)) + 
  geom_point(size = 2.5) + 
  geom_line(aes(group = cov),
            linemitre = 2, size = 0.6) + 
  geom_hline(yintercept = 0.25, aes(group = key)) +
  geom_label_repel(data = plot_balanceimpr %>% filter(key == "All Data"),
                   aes(label = cov),
                   nudge_x = -.3) +
  theme_bw() +
  labs( x = "", y = "Absolute Standardized Difference in Means")


# * Save Figure 3 ---------------------------------------------------------


ggsave(plot_balanceimpr_out, 
       file = "./plots/appendix_figure_3.pdf", 
       width = 8, height = 4)



# * Diagnostics: Matching balance improvement table --------------------------------------

# imbalance before matching
imb_before <- Matching::MatchBalance(cabinetINC ~ 
                                       match_aiddata_AidGDP_ln +
                                       log(match_gdp) +
                                       log(match_pop) +
                                       conf_intens + # conf_intens is already pre-treatment
                                       match_nonstate +
                                       log(match_WBnatres + 1)  +
                                       match_polity, 
                                     data = match_democ_data, 
                                     digits = 2,
                                     ks = T, print.level = 0) # data before matching

# note that order of covariates in MatchBalance is important to get row names right
imbalance_tab_before <- ebal::baltest.collect(imb_before, 
                                              c("Aid / GDP (log)", 
                                                "GDP / PC (log)",
                                                "Population (log)", 
                                                "Conflict Intensity",
                                                "Nonstate Conflict",
                                                "Natural Resource Rents (log)", 
                                                "Regime Type (Polity)"), 
                                              after = F)
# do not report all statistics
imbalance_tab_before <- imbalance_tab_before[, c("mean.Tr", 
                                                 "mean.Co", 
                                                 "T pval", 
                                                 "KS pval")]

colnames(imbalance_tab_before) <-  c("Mean Treated", 
                                     "Mean Control", 
                                     "P-Value T-Test", 
                                     "P-Value K-S Test")

# Imbalance After Matching
imb_after <- Matching::MatchBalance(cabinetINC ~ 
                                      match_aiddata_AidGDP_ln +
                                      log(match_gdp) +
                                      log(match_pop) +
                                      conf_intens + # conf_intens is already pre-treatment
                                      match_nonstate +
                                      log(match_WBnatres + 1)  +
                                      match_polity, 
                                    data = match_democ_df, 
                                    digits = 2,
                                    ks = T, print.level = 0) # data before matching

# note that order of covariates in MatchBalance is important to get row names right
imbalance_tab_after<- ebal::baltest.collect(imb_after, 
                                            c("Aid / GDP (log)", 
                                              "GDP / PC (log)",
                                              "Population (log)", 
                                              "Conflict Intensity",
                                              "Nonstate Conflict",
                                              "Natural Resource Rents (log)", 
                                              "Regime Type (Polity)"), 
                                            after = F)
imbalance_tab_after <- imbalance_tab_after[, c("mean.Tr", 
                                               "mean.Co", 
                                               "T pval", 
                                               "KS pval")]

colnames(imbalance_tab_after) <- c("Mean Treated", 
                                   "Mean Control", 
                                   "P-Value T-Test", 
                                   "P-Value K-S Test")


# Balance tables before / after output


# * Save Table 4 ----------------------------------------------------------


print(xtable(imbalance_tab_before), booktabs = T, type = "html", floating = F,
      file = "./tables/appendix_table_4_before.html")
print(xtable(imbalance_tab_after), booktabs = T, type = "html", floating = F,
      file = "./tables/appendix_table_4_after.html")


# Section 5: Alternative Explanations: UN + ELF Rob checks -----------------------------------------------------


# * Democ scores: UN + ELF ----------------------------------------------------------------


model_polity_cabinc_unelf <- felm(polity2_t2 ~  
                                    cabinetINC * 
                                    aiddata_AidGDP_ln +
                                    log(GDP_per_capita) +
                                    ln_pop +
                                    conf_intens +
                                    nonstate + 
                                    WBnatres +
                                    polity2 +
                                    un_dummy + Ethnic
                                  | year  | 0 | GWNo,
                                  data=diss_df)

model_polity_cabcount_unelf <- felm(polity2_t2 ~  
                                      cabinetCOUNT * 
                                      aiddata_AidGDP_ln +
                                      log(GDP_per_capita) +
                                      ln_pop +
                                      conf_intens +
                                      nonstate + 
                                      WBnatres +
                                      polity2 +
                                      un_dummy + Ethnic
                                    | year | 0 | GWNo,
                                    data=diss_df)


# * Elections - UN + ELF------------------------------------------

load("./data/nelda_ps.rda")
nelda_ps$un_dummy <- ifelse(nelda_ps$DS_ordinal != 0, 1, 0)

model_elec_cabinc_rob_unelf <- felm(v2xel_frefair ~ 
                                      aid_ln *  
                                      cabinetINC.12 +
                                      WBnatres + 
                                      fh + 
                                      nonstate + 
                                      conf_intens + 
                                      log(gdp_per_capita_un) + 
                                      log(population) +
                                      Ethnic + un_dummy
                                    | year | 0 | country
                                    ,
                                    data = nelda_ps)


model_elec_cabcount_rob_unelf <- felm(v2xel_frefair ~ 
                                        aid_ln *  
                                        cabinetCOUNT.12 +
                                        WBnatres + 
                                        fh + 
                                        nonstate + 
                                        conf_intens + 
                                        log(gdp_per_capita_un) + 
                                        log(population) +
                                        Ethnic + un_dummy
                                      | year | 0 | country
                                      ,
                                      data = nelda_ps)


# * Rule of Law: UN + ELF ---------------------------------------------------

model_LJI_rob_cabinc_unelf <- felm(LJI_t2 ~
                                     cabinetINC *
                                     aiddata_AidGDP_ln +
                                     ln_gdp_pc +
                                     ln_pop +
                                     conf_intens +
                                     nonstate + 
                                     WBnatres + 
                                     fh +
                                     Ethnic + un_dummy
                                   | year | 0 | GWNo
                                   ,
                                   data = diss_df)


model_LJI_rob_cabcount_unelf <- felm(LJI_t2 ~
                                       cabinetCOUNT *
                                       aiddata_AidGDP_ln +
                                       ln_gdp_pc +
                                       ln_pop +
                                       conf_intens +
                                       nonstate + 
                                       WBnatres + 
                                       fh +
                                       Ethnic + un_dummy
                                     | year | 0 | GWNo
                                     ,
                                     data = diss_df)


# * Public Goods : UN + ELF--------------------------------------------------

model_spending_cabinc_rob_unelf <- felm(v2dlencmps_t1 ~
                                          cabinetINC *  
                                          aiddata_AidGDP_ln +
                                          ln_gdp_pc +
                                          ln_pop +
                                          conf_intens +
                                          nonstate +
                                          WBnatres + 
                                          fh +
                                          Ethnic + un_dummy
                                        | year | 0 | GWNo,
                                        data=diss_df)

model_spending_cabcount_rob_unelf <- felm(v2dlencmps_t1 ~
                                            cabinetCOUNT *  
                                            aiddata_AidGDP_ln +
                                            ln_gdp_pc +
                                            ln_pop +
                                            conf_intens +
                                            nonstate +
                                            WBnatres + 
                                            fh +
                                            Ethnic + un_dummy
                                          | year | 0 | GWNo,
                                          data=diss_df)

# * Save Table 5 --------------------------------------------------------

model_list_robcheck_unelf <- list(model_polity_cabinc_unelf, 
                                  model_polity_cabcount_unelf, 
                                  model_elec_cabinc_rob_unelf, 
                                  model_elec_cabcount_rob_unelf, 
                                  model_LJI_rob_cabinc_unelf, 
                                  model_LJI_rob_cabcount_unelf, 
                                  model_spending_cabinc_rob_unelf, 
                                  model_spending_cabcount_rob_unelf)

coef_name_map <- list(
  # PS vars
  cabinetINC = "Power-Sharing (binary)",
  cabinetINC.12 = "Power-Sharing (binary)",
  cabinetCOUNT = "Power-Sharing (No. of seats)", 
  cabinetCOUNT.12 = "Power-Sharing (No. of seats)",
  
  # aid vars
  dga_gdp_zero = "DGA/GDP (log)", 
  program_aid_gdp_zero = "Program Aid/GDP (log)", 
  commodity_aid_gdp_zero = "Budget Aid/GDP (log)", 
  aiddata_AidGDP_ln = "Aid / GDP (log)",
  aid_ln = "Aid / GDP (log)",
  
  # interaction terms
  "aid_ln:cabinetINC.12" = "Power-Sharing (binary) * Aid",
  "cabinetINC * aiddata_AidGDP_ln" = "Power-Sharing (binary) * Aid",
  "cabinetINC:aiddata_AidGDP_ln" = "Power-Sharing (binary) * Aid",
  "cabinetCOUNT * aiddata_AidGDP_ln" = "Power-Sharing (No. of seats) * Aid", 
  "cabinetCOUNT:aiddata_AidGDP_ln" = "Power-Sharing (No. of seats) * Aid",
  "aid_ln:cabinetCOUNT.12" = "Power-Sharing (No. of seats) * Aid",
  
  # control vars
  "log(GDP_per_capita)" = "GDP p/c (log)",
  ln_gdp_pc = "GDP p/c (log)",
  "log(gdp_per_capita_un)" = "GDP p/c (log)", 
  "log(population)" = "Population (log)",
  ln_pop = "Population (log)",
  conf_intens = "Conflict Intensity",
  nonstate = "Non-State Violence",
  WBnatres = "Nat. Res. Rents",
  polity2 = "Regime Type",
  fh = "Regime Type",
  mean = "UDS",
  polity2inter = "Polity2 (Interregnum)",
  xpolity_inter ="XPolity",
  Ethnic = "Ethnic Frac.",
  un_dummy = "UN PKO")

htmlreg(model_list_robcheck_unelf, 
              stars = c(0.01, 0.05, 0.1),
              custom.coef.map = coef_name_map,
              file = "./tables/appendix_table_5.html", 
        include.lr = F, 
        table = F,
        use.packages = F,
        include.rsquared = F, 
        include.variance = F)




# Section 6: Probing the Aid Conditionality Assumption --------------------


load("./data/nelda_ps.rda")

# Model Aid Cutoff (nelda57 is aid cutoff variable)
model_aidps_aidcutoff <- felm(v2xel_frefair ~ 
                                nelda57 *  
                                cabinetCOUNT.12 + 
                                aid_ln + 
                                WBnatres + 
                                fh + 
                                nonstate + 
                                conf_intens + 
                                log(gdp_per_capita_un) + 
                                log(population) +
                                nelda45
                              | year | 0 | country
                              ,
                              data = nelda_ps)

# Read & aggregate Chinese aid
china_aid <- read_excel("./data/external_input/aiddata_china_1_2.xlsx",
                        sheet = 2)

china_aid_agg <- china_aid %>% 
  group_by(recipient_iso3, year) %>% 
  dplyr::summarize(chinese_aid2011usd = sum(usd_2011, na.rm = T))

china_aid_merged <- left_join(diss_df, china_aid_agg, 
                              by = c("iso3c" = "recipient_iso3", 
                                     "year")) %>% 
  mutate(continent = countrycode(iso3c, "iso3c", "continent")) %>% 
  filter(continent == "Africa") %>% 
  mutate(chinese_aid2011usd = ifelse(is.na(chinese_aid2011usd), 0, chinese_aid2011usd), 
         chinese_aidgdp = chinese_aid2011usd / GDP)

# model chinese aid
model_chineseaid <- felm(polity2_t2 ~  
                           cabinetCOUNT * 
                           log(chinese_aidgdp + 1) + 
                           aiddata_AidGDP_ln +
                           log(GDP_per_capita) +
                           ln_pop +
                           conf_intens +
                           nonstate + 
                           WBnatres +
                           polity2 
                         | year | 0 | GWNo,
                         data=china_aid_merged)

# model output
coef_name_map <- list(
  

  nelda57 = "Aid Cut-Off",
  "log(chinese_aidgdp + 1)" = "Chinese Aid / GDP (log)",
  
  # PS vars
  cabinetINC = "Power-Sharing (binary)",
  cabinetINC.12 = "Power-Sharing (binary)",
  cabinetCOUNT = "Power-Sharing (No. of seats)", 
  cabinetCOUNT.12 = "Power-Sharing (No. of seats)",
  
  # aid vars
  dga_gdp_zero = "DGA/GDP (log)", 
  program_aid_gdp_zero = "Program Aid/GDP (log)", 
  commodity_aid_gdp_zero = "Budget Aid/GDP (log)", 
  
  
  # interaction terms
  "aid_ln:cabinetINC.12" = "Power-Sharing (binary) * Aid",
  "cabinetINC * aiddata_AidGDP_ln" = "Power-Sharing (binary) * Aid",
  "cabinetINC:aiddata_AidGDP_ln" = "Power-Sharing (binary) * Aid",
  "cabinetCOUNT * aiddata_AidGDP_ln" = "Power-Sharing (No. of seats) * Aid", 
  "cabinetCOUNT:aiddata_AidGDP_ln" = "Power-Sharing (No. of seats) * Aid",
  "aid_ln:cabinetCOUNT.12" = "Power-Sharing (No. of seats) * Aid",
  "nelda57:cabinetCOUNT.12" = "Power-Sharing (No. of seats) * Aid Cut-Off",
  
  # chinese aid
  "cabinetCOUNT:log(chinese_aidgdp + 1)" = "Power-Sharing (No. of seats) * Chinese Aid", 
  
  aiddata_AidGDP_ln = "Aid / GDP (log)",
  aiddata_AidGDP = "Aid / GDP (not log-transformed)",
  aid_ln = "Aid / GDP (log)",
  
  # control vars
  # ps_share = "PS (cabinet share),
  # "ps_share * aiddata_AidGDP_ln" = "PS (cabinet share) * Aid",
  "log(GDP_per_capita)" = "GDP p/c (log)",
  ln_gdp_pc = "GDP p/c (log)",
  "log(gdp_per_capita_un)" = "GDP p/c (log)", 
  "log(population)" = "Population (log)",
  ln_pop = "Population (log)",
  conf_intens = "Conflict Intensity",
  nonstate = "Non-State Violence",
  WBnatres = "Nat. Res. Rents",
  polity2 = "Regime Type",
  fh = "Regime Type",
  mean = "UDS",
  polity2inter = "Polity2 (Interregnum)",
  xpolity_inter ="XPolity",
  Ethnic = "Ethnic Frac.",
  un_dummy = "UN PKO"
)



# * Save Table 6 ----------------------------------------------------------



htmlreg(l = list(model_aidps_aidcutoff, 
                 model_chineseaid), 
        stars = c(0.01, 0.05, 0.1),
        custom.coef.map = coef_name_map,
        file = "./tables/appendix_table_6.html", 
        include.lr = F, 
        table = F,
        use.packages = F,
        include.rsquared = F, 
        include.variance = F)



# Section 7: Additional Robustness Checks---------------------------------


# * UDS -------------------------------------------------------------

# prepare data

# Loda data 
uds <- read_csv("./data/external_input/uds_summary.csv") %>% 
  rename(GWNo = cowcode)

# helper function
source("./code/functions/laggedVar.R")

# Data preparation
diss_df <- left_join(diss_df, uds, 
                     by = c("GWNo", "year"))
diss_df <- laggedVar(diss_df, uds, lVar="mean", tID ="year", gID="GWNo", lagBy = -2)

# cabinc
model_uds_cabinc <- felm(mean_t2 ~  
                          cabinetINC * 
                          aiddata_AidGDP_ln +
                          log(GDP_per_capita) +
                          ln_pop +
                          conf_intens +
                          nonstate + 
                          WBnatres +
                          mean
                        | year  | 0 | GWNo,
                        data=diss_df)


# cabcount
model_uds_cabcount <- felm(mean_t2 ~  
                          cabinetCOUNT * 
                          aiddata_AidGDP_ln +
                          log(GDP_per_capita) +
                          ln_pop +
                          conf_intens +
                          nonstate + 
                          WBnatres +
                          mean 
                        | year | 0 | GWNo,
                        data=diss_df)


# * XPOLITY + Interregnum ---------------------------------------------------


# First load regular Plumper & Neumayer correction
load("./data/external_input/polity2_xpolity_plumper_corrected.rdata")
names(polity_rev)[2] <- "GWNo"

# Fix Serbia for correct merging
polity_rev$GWNo <- ifelse(polity_rev$country == "Yugoslavia", 345, polity_rev$GWNo)
polity_rev$GWNo <- ifelse(polity_rev$country == "Serbia and Montenegro", 345, polity_rev$GWNo)

polity_rev_orig <- polity_rev


# Second load xpolity combined with Plumper & Neumayer correction
load("./data/external_input/polity2_xpolity_plumper_corrected_combined.rdata")
names(polity_rev)[2] <- "GWNo"

# Fix Serbia
polity_rev$GWNo <- ifelse(polity_rev$country == "Yugoslavia", 345, polity_rev$GWNo)
polity_rev$GWNo <- ifelse(polity_rev$country == "Serbia and Montenegro", 345, polity_rev$GWNo)

polity_rev <- left_join(polity_rev_orig, 
                        polity_rev[, c("GWNo", "year", "xpolity_inter", 
                                       "xpolity_max", 
                                       "xpolity_min")], 
                        by = c("GWNo", "year"))

# merge xpolity & interregnum data in main data set
diss_df_xpolity <- merge(diss_df, polity_rev[, c("GWNo", "year", 
                                        "polity2min", "polity2max", "polity2inter",
                                        "xpolity_inter", 
                                        "xpolity_max", 
                                        "xpolity_min")], 
                         by = c("GWNo", "year"), all.x = TRUE)


source("./code/functions/laggedVar.R")

#### For Plumper & Neumayer correction

# Polity 2 Min
diss_df_xpolity <- laggedVar(diss_df_xpolity, 
                             polity_rev, 
                             lVar="polity2min", 
                             tID ="year", gID="GWNo", lagBy = -2)

# Polity2 Max
diss_df_xpolity <- laggedVar(diss_df_xpolity, 
                             polity_rev, 
                             lVar="polity2max", 
                             tID ="year", gID="GWNo", lagBy = -2)

# Polity2 Inter
diss_df_xpolity <- laggedVar(diss_df_xpolity, 
                             polity_rev, 
                             lVar="polity2inter", tID ="year", gID="GWNo", lagBy = -2)

#### XPOLITY

# xpolity min
diss_df_xpolity <- laggedVar(diss_df_xpolity, 
                             polity_rev, 
                             lVar="xpolity_min", 
                             tID ="year", gID="GWNo", lagBy = -2)

# xpolity max
diss_df_xpolity <- laggedVar(diss_df_xpolity, 
                             polity_rev, 
                             lVar="xpolity_max", 
                             tID ="year", gID="GWNo", lagBy = -2)

# xpolity inter
diss_df_xpolity <- laggedVar(diss_df_xpolity, 
                             polity_rev, 
                             lVar="xpolity_inter", tID ="year", gID="GWNo", lagBy = -2)



# XPOLITY
xpolity_model_cabinc <- felm(xpolity_inter_t2 ~  
                               cabinetINC * 
                               aiddata_AidGDP_ln  +
                               log(GDP_per_capita) +
                               log(population) +
                               conf_intens +
                               nonstate + 
                               WBnatres +
                               xpolity_inter
                             | year | 0 | GWNo,
                             data=diss_df_xpolity)

xpolity_model_cabcount <- felm(xpolity_inter_t2 ~  
                               cabinetCOUNT * 
                               aiddata_AidGDP_ln  +
                               log(GDP_per_capita) +
                               log(population) +
                               conf_intens +
                               nonstate + 
                               WBnatres +
                               xpolity_inter
                             | year | 0 | GWNo,
                             data=diss_df_xpolity)

# Interregnum Bias
interregnum_model_cabinc <- felm(polity2inter_t2 ~  
                                   cabinetINC * 
                                   aiddata_AidGDP_ln +
                                   log(GDP_per_capita) +
                                   log(population) +
                                   conf_intens +
                                   nonstate + 
                                   WBnatres +
                                   polity2inter
                                 | year | 0 | GWNo,
                                 data=diss_df_xpolity)

interregnum_model_cabcount <- felm(polity2inter_t2 ~  
                                   cabinetCOUNT * 
                                   aiddata_AidGDP_ln +
                                   log(GDP_per_capita) +
                                   log(population) +
                                   conf_intens +
                                   nonstate + 
                                   WBnatres +
                                   polity2inter
                                 | year | 0 | GWNo,
                                 data=diss_df_xpolity)



model_list_robcheck <- list(model_uds_cabinc, 
                            model_uds_cabcount, 
                            xpolity_model_cabinc, 
                            xpolity_model_cabcount, 
                            interregnum_model_cabinc, 
                            interregnum_model_cabcount)



# * Elections: NELDA --------------------------------------------------------
load("./data/nelda_ps.rda")

model_nelda_cabinc <- felm(quality ~ 
                             aid_ln *  
                             cabinetINC.12 +
                             WBnatres + 
                             fh + 
                             nonstate + 
                             conf_intens + 
                             log(gdp_per_capita_un) + 
                             log(population) 
                           | year | 0 | country
                           ,
                           data = nelda_ps)

model_nelda_cabcount <- felm(quality ~ 
                             aid_ln *  
                             cabinetCOUNT.12 +
                             WBnatres + 
                             fh + 
                             nonstate + 
                             conf_intens + 
                             log(gdp_per_capita_un) + 
                             log(population) 
                           | year | 0 | country
                           ,
                           data = nelda_ps)


# * Rule of Law -------------------------------------------------------------

model_v2xjucon_cabinc <- felm(v2x_jucon_t2 ~
                                cabinetINC *
                                aiddata_AidGDP_ln +
                                ln_gdp_pc +
                                ln_pop +
                                conf_intens +
                                nonstate + 
                                WBnatres + 
                                fh
                              | year | 0 | GWNo
                              ,
                              data = diss_df)


model_v2xjucon_cabcount <- felm(v2x_jucon_t2 ~
                                  cabinetCOUNT *
                                  aiddata_AidGDP_ln +
                                  ln_gdp_pc +
                                  ln_pop +
                                  conf_intens +
                                  nonstate + 
                                  WBnatres + 
                                  fh
                                | year | 0 | GWNo
                                ,
                                data = diss_df)


# * Public Goods ------------------------------------------------------------


model_v2xcorr_cabinc <- felm(v2x_corr_t1 ~
                               cabinetINC *  
                               aiddata_AidGDP_ln +
                               ln_gdp_pc +
                               ln_pop +
                               conf_intens +
                               nonstate +
                               WBnatres + 
                               fh
                             | year | 0 | GWNo,
                             data=diss_df)


model_v2xcorr_cabcount <- felm(v2x_corr_t1 ~
                                 cabinetCOUNT *  
                                 aiddata_AidGDP_ln +
                                 ln_gdp_pc +
                                 ln_pop +
                                 conf_intens +
                                 nonstate +
                                 WBnatres + 
                                 fh
                               | year | 0 | GWNo,
                               data=diss_df)


# * Model output ---------------------------------------------------------

model_list_techrob <- list(model_uds_cabinc, 
                           model_uds_cabcount, 
                           
                           xpolity_model_cabinc, 
                           xpolity_model_cabcount,
                           
                           interregnum_model_cabinc, 
                           interregnum_model_cabcount,
                           
                           model_nelda_cabinc, 
                           model_nelda_cabcount, 
                           
                           model_v2xjucon_cabinc, 
                           model_v2xjucon_cabcount, 
                           
                           model_v2xcorr_cabinc, 
                           model_v2xcorr_cabcount)

coef_name_map <- list(
  # PS vars
  cabinetINC = "Power-Sharing (binary)",
  cabinetINC.12 = "Power-Sharing (binary)",
  cabinetCOUNT = "Power-Sharing (No. of seats)", 
  cabinetCOUNT.12 = "Power-Sharing (No. of seats)",
  
  # aid vars
  dga_gdp_zero = "DGA/GDP (log)", 
  program_aid_gdp_zero = "Program Aid/GDP (log)", 
  commodity_aid_gdp_zero = "Budget Aid/GDP (log)", 
  aiddata_AidGDP_ln = "Aid / GDP (log)",
  aid_ln = "Aid / GDP (log)",
  
  # interaction terms
  "aid_ln:cabinetINC.12" = "Power-Sharing (binary) * Aid",
  "cabinetINC * aiddata_AidGDP_ln" = "Power-Sharing (binary) * Aid",
  "cabinetINC:aiddata_AidGDP_ln" = "Power-Sharing (binary) * Aid",
  "cabinetCOUNT * aiddata_AidGDP_ln" = "Power-Sharing (No. of seats) * Aid", 
  "cabinetCOUNT:aiddata_AidGDP_ln" = "Power-Sharing (No. of seats) * Aid",
  "aid_ln:cabinetCOUNT.12" = "Power-Sharing (No. of seats) * Aid",
  
  # control vars
  # ps_share = "PS (cabinet share)",
  # "ps_share * aiddata_AidGDP_ln" = "PS (cabinet share) * Aid",
  "log(GDP_per_capita)" = "GDP p/c (log)",
  ln_gdp_pc = "GDP p/c (log)",
  "log(gdp_per_capita_un)" = "GDP p/c (log)", 
  "log(population)" = "Population (log)",
  ln_pop = "Population (log)",
  conf_intens = "Conflict Intensity",
  nonstate = "Non-State Violence",
  WBnatres = "Nat. Res. Rents",
  mean = "UDS",
  xpolity_inter ="XPOLITY",
  polity2inter = "Polity2 (Interregnum)",
  polity2 = "Regime Type",
  fh = "Regime Type",
  Ethnic = "Ethnic Frac.",
  DS_ordinal = "UN PKO")



# * Save Table 8 ----------------------------------------------------------


htmlreg(model_list_techrob, 
              stars = c(0.01, 0.05, 0.1),
              custom.coef.map = coef_name_map,
              file = "./tables/appendix_table_8.html", 
              include.lr = F, 
              table = F,
              use.packages = F,
              include.rsquared = F, 
              include.variance = F)


# Section 7.2: Cross-Section ----------------------------------------------


cs_data <- diss_df %>% 
  ungroup() %>% 
  group_by(country_pc_period)  %>% 
  #dplyr::mutate(cabinetCOUNT_1 = ifelse(year == min(year), cabinetCOUNT, NA),
  #              cabinetINC_1 = ifelse(year == min(year)+1, cabinetINC, NA)) %>% 
  dplyr::summarise(start = min(year),
                   end = max(year),
                   cabinetCOUNT = ifelse(max(cabinetCOUNT) > 0, max(cabinetCOUNT), 0),
                   cabinetINC = ifelse(1 %in% cabinetINC, 1, 0),
                   pol_change = tail(polity2, 1) - head(polity2, 1),
                   pol_inc = ifelse(pol_change > 0, 1, 0),
                   pol_max = max(polity2, na.rm = T),
                   jud_ind = mean(LJI, na.rm = T), 
                   spending = mean(v2dlencmps, na.rm = T),
                   aid = log(mean(aiddata_AidGDP, na.rm = T)),
                   aid_pc = log(mean(aiddata_AidPC, na.rm = T)),
                   gdp = log(mean(GDP_per_capita, na.rm = T)),
                   pop = log(mean(population)),
                   territory = head(territory, 1),
                   natres = first(WBnatres),
                   nonstate = head(nonstate, 1),
                   polity = head(polity2, 1, n),
                   fh = first(fh),
                   conf_intens = head(conf_intens, 1),
                   langfrac = head(langfrac, 1),
                   five_y_out = min(minyear) + 7,
                   valuein2011 = 2010,
                   duration = 2010 - end)


cs_elections <- nelda_ps %>% 
  group_by(pc_period_identifier) %>% 
  summarise(cabinetINC = ifelse(1 %in% cabinetINC, 1, 0), 
            aid = log(mean(aiddata_AidGDP, na.rm = T)), 
            elec_quality = mean(v2xel_frefair, na.rm = T)) 

cs_elections_ag <- cs_elections %>% 
  select(-pc_period_identifier) %>% 
  gather(key, value, -cabinetINC, -aid)

cs_full <- gather(cs_data %>% 
                    select(pol_change, jud_ind, spending, cabinetINC, aid), 
                  key, value, -cabinetINC, -aid)

cs_full <- bind_rows(cs_full, 
                     cs_elections_ag) %>% 
  mutate(key = forcats::fct_relevel(key, c("pol_change", "elec_quality", 
                                           "jud_ind", "spending")))



cs_plots <- ggplot(cs_full, 
                   aes(x = aid, y = value, 
                       group = as.factor(cabinetINC), 
                       color = as.factor(cabinetINC))) +
  geom_point(size = 2, alpha = 0.5) +
  geom_smooth(method  = "lm", se = F) + 
  scale_color_manual("", values = c("#e41a1c", "#377eb8"), 
                     labels = c("No Power-Sharing", "Power-Sharing")) +
  theme_bw() + 
  theme(legend.position = "bottom") +
  facet_wrap(~key, ncol = 2, scales = "free", 
             labeller = labeller(key = c(pol_change = "Polity Score Change", 
                                         elec_quality = "Election Quality", 
                                         jud_ind = "Judicial Independence", 
                                         spending = "Public vs. Private Goods Spending"))) +
  labs(y = "Dependent Variable", x = "Aid/GDP (log)") 



# * Save Figure 4 ---------------------------------------------------------



ggsave(cs_plots, 
       file = "./plots/appendix_figure_4.pdf", 
       width = 5, 
       height = 5, 
       units = "in")



# Section 7.3: Variation by Type of Power-Sharing -------------------------



# * Democracy Scores -------------------------------------------



# Load data
load("./data/diss_df.rda")

# Estimate Models
model_polity_cabinc <- felm(polity2_t2 ~  
                              cabinetINC * 
                              aiddata_AidGDP_ln +
                              log(GDP_per_capita) +
                              ln_pop +
                              conf_intens +
                              nonstate + 
                              WBnatres +
                              polity2 | 0 | 0 | GWNo,
                            data=diss_df)

# Polity DV + seniorINC
model_polity_senior <- lfe::felm(polity2_t2 ~  
                                   seniorINC * 
                                   aiddata_AidGDP_ln +
                                   log(GDP_per_capita) +
                                   ln_pop +
                                   conf_intens +
                                   nonstate + 
                                   WBnatres +
                                   polity2 | 0 | 0 | GWNo ,
                                 data=diss_df)

# Polity DV + nonseniorINC
model_polity_nonsenior <- felm(polity2_t2 ~  
                                 nonseniorINC * 
                                 aiddata_AidGDP_ln +
                                 log(GDP_per_capita) +
                                 ln_pop +
                                 conf_intens +
                                 nonstate + 
                                 WBnatres +
                                 polity2 | 0 | 0 | GWNo,
                               data=diss_df)



mechanism_models <- list("Cabinet PS (Baseline)" = model_polity_cabinc, 
                         "Senior PS" = model_polity_senior, 
                         "Nonsenior PS" = model_polity_nonsenior) %>% 
  enframe() %>% 
  mutate(tidymodel = map(value, broom::tidy)) %>% 
  unnest(tidymodel) %>% 
  filter(grepl(":", term)) %>% 
  mutate(name = forcats::fct_relevel(name, c("Cabinet PS (Baseline)", 
                                             "Senior PS", 
                                             "Nonsenior PS")))
mechanism_models_democ <- mechanism_models


# * Elections  --------------------------------------------------



# Load data 
load("./data/nelda_ps.rda")

model_aidps_quality_cabinc <- felm(quality ~ 
                                     aid_ln *  
                                     cabinetINC.12 +
                                     WBnatres + 
                                     fh + 
                                     nonstate + 
                                     conf_intens + 
                                     log(gdp_per_capita_un) + 
                                     log(population)
                                   | 0 | 0 | country, 
                                   data = nelda_ps)


model_aidps_quality_seninc <- felm(quality ~ 
                                     aid_ln *  
                                     seniorINC.12 +
                                     WBnatres + 
                                     fh + 
                                     nonstate + 
                                     conf_intens + 
                                     log(gdp_per_capita_un) + 
                                     log(population)
                                   | 0 | 0 | country, 
                                   data = nelda_ps)


model_aidps_quality_nonseninc <- felm(quality ~ 
                                        aid_ln *  
                                        nonseniorINC.12 +
                                        WBnatres + 
                                        fh + 
                                        nonstate + 
                                        conf_intens + 
                                        log(gdp_per_capita_un) + 
                                        log(population)
                                      | 0 | 0 | country, 
                                      data = nelda_ps)


# extract coefficients for interaction term
mechanism_models <- list("Cabinet PS (Baseline)" = model_aidps_quality_cabinc, 
                         "Senior PS" = model_aidps_quality_seninc, 
                         "Nonsenior PS" = model_aidps_quality_nonseninc) %>% 
  enframe() %>% 
  mutate(tidymodel = map(value, broom::tidy)) %>% 
  unnest(tidymodel) %>% 
  filter(grepl(":", term)) %>% 
  mutate(name = forcats::fct_relevel(name, c("Cabinet PS (Baseline)", 
                                             "Senior PS", 
                                             "Nonsenior PS")))
mechanism_models_elec <- mechanism_models



# * Rule of Law  ------------------------------------------------

# Data
load("./data/diss_df.rda")



# Prepare data frame for multiple plots
rol_vars <- list(
  cabinetCOUNT = diss_df,
  seniorCOUNT = diss_df, 
  nonseniorCOUNT = diss_df)

# create data frame with list column
rol_vars <- enframe(rol_vars)


# define function that will be applied to every data frame in the list column
main_model <- function(ind_var, data) {
  data <- as.data.frame(data)
  data$ind_var <- data[, ind_var]
  
  if(grepl("COUNT", ind_var)) {
    model <- lfe::felm(LJI_t2 ~
                         ind_var *
                         aiddata_AidGDP_ln +
                         log(GDP_per_capita) +
                         ln_pop +
                         conf_intens +
                         nonstate +
                         WBnatres +
                         fh | 0 | 0 | GWNo,
                       data=data)
    return(model)
    
  } else {
    
  }
  
  
}


# fit models & post-process data for plotting
model_all <- rol_vars %>% 
  dplyr::mutate(model = map2(name, value, ~ main_model(.x, .y))) 

model_out <- model_all %>% 
  mutate(coef = map(model, broom::tidy)) %>% 
  unnest(coef) %>% 
  # keep only interaction term coefs
  filter(grepl(":", term)) %>% 
  dplyr::select(name, estimate, std.error) %>% 
  mutate(name = forcats::fct_relevel(name, 
                                     c("cabinetCOUNT", 
                                       "seniorCOUNT", 
                                       "nonseniorCOUNT")))

model_out_rol <- model_out



# * Public Goods  -----------------------------------------------

# Prepare data frame for multiple plots
spending_vars <- list(
  cabinetCOUNT = diss_df,
  seniorCOUNT = diss_df, 
  nonseniorCOUNT = diss_df)

# create data frame with list column
spending_vars <- enframe(spending_vars)


# define function that will be applied to every data frame in the list column
main_model <- function(ind_var, data) {
  data <- as.data.frame(data)
  data$ind_var <- data[, ind_var]
  
  if(grepl("COUNT", ind_var)) {
    model <- lfe::felm(v2dlencmps_t1 ~
                         ind_var *
                         aiddata_AidGDP_ln +
                         log(GDP_per_capita) +
                         ln_pop +
                         conf_intens +
                         nonstate +
                         WBnatres +
                         fh | 0 | 0 | GWNo,
                       data=data)
    return(model)
    
  } else {
    
  }
  
  
}


# fit models & post-process data for plotting
model_all <- spending_vars %>% 
  dplyr::mutate(model = map2(name, value, ~ main_model(.x, .y))) 

model_out <- model_all %>% 
  mutate(coef = map(model, broom::tidy)) %>% 
  unnest(coef) %>% 
  # keep only interaction term coefs
  filter(grepl(":", term)) %>% 
  dplyr::select(name, estimate, std.error) %>% 
  mutate(name = forcats::fct_relevel(name, 
                                     c("cabinetCOUNT", 
                                       "seniorCOUNT", 
                                       "nonseniorCOUNT")))

model_out_pubgoods <- model_out


# * Combine model estimates -------------------------------------


mechanism_models_democ <- mechanism_models_democ %>% 
  mutate(element = "Democracy Scores")

mechanism_models_elec <- mechanism_models_elec %>% 
  mutate(element = "Election Quality")

model_out_rol <- model_out_rol %>% 
  mutate(element = "Rule of Law")

model_out_pubgoods <- model_out_pubgoods %>% 
  mutate(element = "Public Goods")

all_effects <- bind_rows(mechanism_models_democ, mechanism_models_elec) %>% 
  bind_rows(., model_out_rol) %>% 
  bind_rows(., model_out_pubgoods)

all_effects <- all_effects %>% 
  filter(grepl("(S|s)enior", name)) %>% 
  mutate(name = stringr::str_replace_all(name, "nonseniorCOUNT", "Nonsenior PS"), 
         name = stringr::str_replace_all(name, "seniorCOUNT", "Senior PS")) %>% 
  mutate(element = forcats::fct_relevel(element, c("Democracy Scores", 
                                                   "Election Quality", 
                                                   "Rule of Law", 
                                                   "Public Goods")))


all_effects_plot <- ggplot(all_effects, 
                           aes(x = name, 
                               y = estimate)) +
  geom_point() + 
  geom_errorbar(aes(ymin = estimate - 1.67 * std.error, 
                    ymax = estimate + 1.67 * std.error),
                width = 0) +
  facet_wrap( ~ element, scales = "free_y", nrow = 1) +
  scale_x_discrete(labels = c("Nonsenior \n PS", "Senior \n PS")) +
  theme_bw() +
  labs(y = "Coefficient Estimate \n of the Interaction Term", x = "") +
  theme(panel.grid = element_blank())



# * Save Figure 5 -----------------------------------------------------------

ggsave(plot = all_effects_plot,
       height = 6.5, width = 16, scale = 0.5, 
       file = "./plots/appendix_figure_5.pdf")




# Section 7.4: Logged vs. Non-logged Aid -----------------------------------------------

model_aidlog <- felm(polity2_t2 ~  
                              cabinetINC * 
                              aiddata_AidGDP_ln +
                              log(GDP_per_capita) +
                              ln_pop +
                              conf_intens +
                              nonstate + 
                              WBnatres +
                              polity2 
                            | year | 0 | GWNo,
                            data=diss_df )

model_aidnormal <- felm(polity2_t2 ~  
                          cabinetINC * 
                          aiddata_AidGDP +
                          log(GDP_per_capita) +
                          ln_pop +
                          conf_intens +
                          nonstate + 
                          WBnatres +
                          polity2 
                        | year | 0 | GWNo,
                        data=diss_df )



coef_name_map <- list(
  
  nelda57 = "Aid Cut-Off",
  "log(chinese_aidgdp + 1)" = "Chinese Aid / GDP (log)",
  
  # PS vars
  cabinetINC = "Power-Sharing (binary)",
  cabinetINC.12 = "Power-Sharing (binary)",
  cabinetCOUNT = "Power-Sharing (No. of seats)", 
  cabinetCOUNT.12 = "Power-Sharing (No. of seats)",
  
  # aid vars
  dga_gdp_zero = "DGA/GDP (log)", 
  program_aid_gdp_zero = "Program Aid/GDP (log)", 
  commodity_aid_gdp_zero = "Budget Aid/GDP (log)", 
  
  # interaction terms
  "aid_ln:cabinetINC.12" = "Power-Sharing (binary) * Aid",
  "cabinetINC * aiddata_AidGDP_ln" = "Power-Sharing (binary) * Aid (log transformed)",
  "cabinetINC:aiddata_AidGDP_ln" = "Power-Sharing (binary) * Aid",
  "cabinetCOUNT * aiddata_AidGDP_ln" = "Power-Sharing (No. of seats) * Aid", 
  "cabinetCOUNT:aiddata_AidGDP_ln" = "Power-Sharing (No. of seats) * Aid",
  "aid_ln:cabinetCOUNT.12" = "Power-Sharing (No. of seats) * Aid",
  "nelda57:cabinetCOUNT.12" = "Power-Sharing (No. of seats) * Aid Cut-Off",
  "cabinetINC:aiddata_AidGDP" = "Power-Sharing (binary) * Aid / GDP (not log-transformed)",
  
  # chinese aid
  "cabinetCOUNT:log(chinese_aidgdp + 1)" = "Power-Sharing (No. of seats) * Chinese Aid", 
  
  aiddata_AidGDP_ln = "Aid / GDP (log)",
  aiddata_AidGDP = "Aid / GDP (not log-transformed)",
  aid_ln = "Aid / GDP (log)",
  
  # control vars

  "log(GDP_per_capita)" = "GDP p/c (log)",
  ln_gdp_pc = "GDP p/c (log)",
  "log(gdp_per_capita_un)" = "GDP p/c (log)", 
  "log(population)" = "Population (log)",
  ln_pop = "Population (log)",
  conf_intens = "Conflict Intensity",
  nonstate = "Non-State Violence",
  WBnatres = "Nat. Res. Rents",
  polity2 = "Regime Type",
  fh = "Regime Type",
  mean = "UDS",
  polity2inter = "Polity2 (Interregnum)",
  xpolity_inter ="XPolity",
  Ethnic = "Ethnic Frac.",
  un_dummy = "UN PKO"
)


# * Save Table 9 ----------------------------------------------------------

htmlreg(l = list(model_aidlog, 
                       model_aidnormal), 
              stars = c(0.01, 0.05, 0.1),
              custom.coef.map = coef_name_map,
              file = "./tables/appendix_table_9.html", 
        include.lr = F, 
        table = F,
        use.packages = F,
        include.rsquared = F, 
        include.variance = F)


# Section 7.5: Variation over Time ----------------------------------------



# * Democracy Scores - Temporal Dynamics ------------------------------------

# Data
load("./data/diss_df.rda")

# Prepare data frame for multiple plots
polity_vars <- list(
  polity2_t1 = diss_df,
  polity2_t2 = diss_df, 
  polity2_t3 = diss_df, 
  polity2_t4 = diss_df, 
  polity2_t5 = diss_df)

# create data frame with list column
polity_vars <- enframe(polity_vars)

# define function that will be applied to every data frame in the list column
main_model <- function(lead_type, data) {
  data <- as.data.frame(data)
  data$lead_var <- data[, grep(lead_type, names(data), value =T)]
  
  
  model <- lfe::felm(lead_var ~
                       cabinetCOUNT *
                       aiddata_AidGDP_ln +
                       log(GDP_per_capita) +
                       ln_pop +
                       conf_intens +
                       nonstate +
                       WBnatres +
                       polity2 | year | 0 | GWNo,
                     data=data)
  return(model)
  
}


# fit models & post-process data for plotting
model_all <- polity_vars %>% 
  mutate(model = map2(name, value, ~ main_model(.x, .y))) 

model_out <- model_all %>% 
  mutate(coef = map(model, broom::tidy)) %>% 
  unnest(coef) %>% 
  # keep only interaction term coefs
  filter(term == "cabinetCOUNT:aiddata_AidGDP_ln") %>% 
  mutate(dem_score = ifelse(grepl("polity", name), "Polity", name)) %>% 
  dplyr::select(dem_score, name, estimate, std.error) %>% 
  group_by(dem_score) %>% 
  mutate(name = 1:5)

temp_dyn_democ <- model_out


# * Elections - Temporal Dynamics -------------------------------------------


load("./data/nelda_ps.rda")

# different elections

nelda_ps <- nelda_ps %>% 
  group_by(country) %>% 
  mutate(el_no = dense_rank(year)) %>% 
  mutate(el_no = as.numeric(ifelse(el_no >= 2, 2, el_no)))

model_aidps_quality_cabinc_first <- felm(v2xel_frefair ~ 
                                           aid_ln *  
                                           cabinetINC.12 +
                                           WBnatres + 
                                           fh + 
                                           nonstate + 
                                           conf_intens + 
                                           log(gdp_per_capita_un) + 
                                           log(population)
                                         | year  | 0 | country
                                         ,
                                         data = nelda_ps %>% filter(el_no == 1))

model_aidps_quality_cabinc_first <- broom::tidy(model_aidps_quality_cabinc_first)
model_aidps_quality_cabinc_first$name <- 1


model_aidps_quality_cabinc_second <- felm(v2xel_frefair ~ 
                                            aid_ln *  
                                            cabinetINC.12 +
                                            WBnatres + 
                                            fh + 
                                            # nonstate + 
                                            conf_intens + 
                                            log(gdp_per_capita_un) + 
                                            log(population)
                                          | year | 0 | country
                                          ,
                                          data = nelda_ps %>% filter(el_no == 2))

model_aidps_quality_cabinc_second <- broom::tidy(model_aidps_quality_cabinc_second)
model_aidps_quality_cabinc_second$name <- 2

election_timing <- bind_rows(model_aidps_quality_cabinc_first, 
                             model_aidps_quality_cabinc_second) %>% 
  filter(term == "aid_ln:cabinetINC.12") %>% 
  mutate(dem_score = "Elections") %>% 
  select(dem_score, estimate, std.error, name)



# * Rule of Law - Temporal Dynamics -----------------------------------------

load("./data/diss_df.rda")
diss_df <- diss_df %>% 
  dplyr::select(-matches("logit")) 



# Prepare data frame for multiple plots
judind_vars <- list(
  LJI_t1 = diss_df,
  LJI_t2 = diss_df, 
  LJI_t3 = diss_df, 
  LJI_t4 = diss_df, 
  LJI_t5 = diss_df)

# create data frame with list column
judind_vars <- enframe(judind_vars)

# define function that will be applied to every data frame in the list column
main_model <- function(lead_type, data) {
  data <- as.data.frame(data)
  data$lead_var <- data[, grep(lead_type, names(data), value =T)]
  
  
  model <- lfe::felm(lead_var ~
                       cabinetCOUNT *
                       aiddata_AidGDP_ln +
                       log(GDP_per_capita) +
                       ln_pop +
                       conf_intens +
                       nonstate +
                       WBnatres +
                       fh | year | 0 | GWNo,
                     data=data)
  return(model)
  
}
# fit models & post-process data for plotting
model_all <- judind_vars %>% 
  dplyr::mutate(model = map2(name, value, ~ main_model(.x, .y))) 

model_out <- model_all %>% 
  mutate(coef = map(model, broom::tidy)) %>% 
  unnest(coef) %>% 
  # keep only interaction term coefs
  filter(term == "cabinetCOUNT:aiddata_AidGDP_ln") %>% 
  mutate(dem_score = ifelse(grepl("LJI", name), "Rule of Law", name)) %>% 
  dplyr::select(dem_score, name, estimate, std.error) %>% 
  group_by(dem_score) %>% 
  mutate(name = 1:5)


temp_dyn_rol <- model_out


# * Public Goods - Temporal Dynamics ----------------------------------------

diss_df <- diss_df %>% 
  dplyr::select(-matches("logit")) 

# Prepare data frame for multiple plots
spending_vars <- list(
  v2dlencmps_t1 = diss_df,
  v2dlencmps_t2 = diss_df, 
  v2dlencmps_t3 = diss_df, 
  v2dlencmps_t4 = diss_df, 
  v2dlencmps_t5 = diss_df)

# create data frame with list column
spending_vars <- enframe(spending_vars)

# define function that will be applied to every data frame in the list column
main_model <- function(lead_type, data) {
  data <- as.data.frame(data)
  data$lead_var <- data[, grep(lead_type, names(data), value =T)]
  model <- lfe::felm(lead_var ~
                       cabinetCOUNT *
                       aiddata_AidGDP_ln +
                       log(GDP_per_capita) +
                       ln_pop +
                       conf_intens +
                       nonstate +
                       WBnatres +
                       fh | 0 | 0 | GWNo,
                     data=data)
  return(model)
  
}


# fit models & post-process data for plotting
model_all <- spending_vars %>% 
  dplyr::mutate(model = map2(name, value, ~ main_model(.x, .y))) 

model_out <- model_all %>% 
  mutate(coef = map(model, broom::tidy)) %>% 
  unnest(coef) %>% 
  # keep only interaction term coefs
  filter(term == "cabinetCOUNT:aiddata_AidGDP_ln") %>% 
  mutate(dem_score = ifelse(grepl("v2dlencmps", name), "Public vs. Particularistic Spending", name)) %>% 
  dplyr::select(dem_score, name, estimate, std.error) %>% 
  group_by(dem_score) %>% 
  mutate(name = 1:5)

temp_dyn_pubgoods <- model_out

# Output - Temporal Dynamics ----------------------------------------------


all_temp_dyn <- temp_dyn_democ %>% 
  bind_rows(., election_timing) %>% 
  bind_rows(., temp_dyn_rol) %>% 
  bind_rows(., temp_dyn_pubgoods)


all_temp_dyn <- all_temp_dyn %>% 
  ungroup() %>% 
  mutate(dv = c(rep("Democracy Scores", 5),
                rep("Elections", 2),
                rep("Rule of Law", 5), 
                rep("Public Goods", 5))) %>% 
  group_by(dv) %>% 
  ungroup() %>% 
  mutate(dv = forcats::fct_relevel(dv, c("Democracy Scores", 
                                         "Elections", 
                                         "Rule of Law", 
                                         "Public Goods")))




# Plot - Temporal Dynamics ------------------------------------------------


all_temp_dyn_plot <- ggplot(all_temp_dyn, 
                            aes(x = name, 
                                y = estimate,
                                group = dem_score)) +
  geom_point( aes(group = dem_score), size = 1.7, 
              position = position_dodge(width = .5)) + 
  
  geom_errorbar(aes(ymin = estimate - 1.67 * std.error, 
                    ymax = estimate + 1.67 * std.error  ), 
                width = 0,
                position = position_dodge(width = .5)) +
  
  geom_hline(yintercept = 0, linetype = 2) +
  theme_bw()+ 
  labs(x = "Year after t0 / First or Second Elections", y = "Estimate of the Interaction Term") +
  theme(legend.position = "bottom", 
        panel.grid = element_blank()) +
  # theme(legend.key.size=unit(3,"lines")) +
  scale_x_continuous(breaks = seq(0,5,1)) +
  
  facet_wrap(~dv, nrow = 1, scales = "free") 


# * Save Figure 6 ---------------------------------------------------------


ggsave(plot = all_temp_dyn_plot,height = 6.5, width = 16, scale = 0.5,
       file = "./plots/appendix_figure_6.pdf")


# Section 7.6: Decade Fixed Effects -------------------------------------------------


model_polity_decadeFE <- felm(polity2_t2 ~  
                              cabinetINC * 
                              aiddata_AidGDP_ln +
                              log(GDP_per_capita) +
                              ln_pop +
                              conf_intens +
                              nonstate + 
                              WBnatres +
                              polity2 
                            | I(year >= 2000) | 0 | GWNo,
                            data=diss_df )


model_elections_decadeFE <- felm(v2xel_frefair ~ 
                                     aid_ln *  
                                     cabinetINC.12 +
                                     WBnatres + 
                                     fh + 
                                     nonstate + 
                                     conf_intens + 
                                     log(gdp_per_capita_un) + 
                                     log(population)
                                   | I(year >= 2000) | 0 | country
                                   ,
                                   data = nelda_ps)



model_judind_decadeFE <- felm(LJI_t2 ~
                                       cabinetINC *
                                       aiddata_AidGDP_ln +
                                       ln_gdp_pc +
                                       ln_pop +
                                       conf_intens +
                                       nonstate + 
                                       WBnatres + 
                                       fh
                                     | I(year >= 2000)  | 0 | GWNo
                                     ,
                                     data = diss_df)


model_spending_decadeFE <- felm(v2dlencmps_t1 ~
                                      cabinetINC *  
                                      aiddata_AidGDP_ln +
                                      ln_gdp_pc +
                                      ln_pop +
                                      conf_intens +
                                      nonstate +
                                      WBnatres + 
                                      fh
                                    | I(year >= 2000)  | 0 | GWNo,
                                    data=diss_df)

model_list <- list(model_polity_decadeFE, 
                   model_elections_decadeFE, 
                   model_judind_decadeFE, 
                   model_spending_decadeFE)

coef_name_map <- list(
  # PS vars
  cabinetINC = "Power-Sharing (binary)",
  cabinetINC.12 = "Power-Sharing (binary)",
  cabinetCOUNT = "Power-Sharing (No. of seats)", 
  cabinetCOUNT.12 = "Power-Sharing (No. of seats)",
  
  # aid vars
  dga_gdp_zero = "DGA/GDP (log)", 
  program_aid_gdp_zero = "Program Aid/GDP (log)", 
  commodity_aid_gdp_zero = "Budget Aid/GDP (log)", 
  aiddata_AidGDP_ln = "Aid / GDP (log)",
  aid_ln = "Aid / GDP (log)",
  
  # interaction terms
  "aid_ln:cabinetINC.12" = "Power-Sharing (binary) * Aid",
  "cabinetINC * aiddata_AidGDP_ln" = "Power-Sharing (binary) * Aid",
  "cabinetINC:aiddata_AidGDP_ln" = "Power-Sharing (binary) * Aid",
  "cabinetCOUNT * aiddata_AidGDP_ln" = "Power-Sharing (No. of seats) * Aid", 
  "cabinetCOUNT:aiddata_AidGDP_ln" = "Power-Sharing (No. of seats) * Aid",
  "aid_ln:cabinetCOUNT.12" = "Power-Sharing (No. of seats) * Aid",
  
  # control vars
  # ps_share = "PS (cabinet share)",
  # "ps_share * aiddata_AidGDP_ln" = "PS (cabinet share) * Aid",
  "log(GDP_per_capita)" = "GDP p/c (log)",
  ln_gdp_pc = "GDP p/c (log)",
  "log(gdp_per_capita_un)" = "GDP p/c (log)", 
  "log(population)" = "Population (log)",
  ln_pop = "Population (log)",
  conf_intens = "Conflict Intensity",
  nonstate = "Non-State Violence",
  WBnatres = "Nat. Res. Rents",
  polity2 = "Regime Type",
  fh = "Regime Type",
  election_promise = "Election Promise in PA", 
  Ethnic = "Ethnic Frac.",
  DS_ordinal = "UN PKO")


# * Save Table 10 ---------------------------------------------------------


htmlreg(model_list, 
              stars = c(0.01, 0.05, 0.1),
              custom.coef.map = coef_name_map,
              file = "./tables/appendix_table_10.html",
        include.lr = F, 
        table = F,
        use.packages = F,
        include.rsquared = F, 
        include.variance = F)

# Section 7.7: Election Promises ----------------------------------------------

load("./data/diss_df.rda")
load("./data/nelda_ps.rda")

# Data preparation from PSED
psed <- readxl::read_excel("./data/external_input/PSED_dyad.xlsx")

# aggregate election promises by post-conflict country
psed_elec <- psed %>% 
  group_by(GWNo, location, dyadID) %>% 
  dplyr::mutate(startyear = lubridate::year(PostStartDate), 
         endyear = dplyr::lead(startyear), 
         endyear = ifelse(is.na(endyear), 
                          startyear + 6, 
                          endyear)) %>% 
  group_by(GWNo, location, startyear, endyear, dyadID) %>% 
  dplyr::summarise(other_parlelect = ifelse(any(1 %in% other_parlelect), 1, 0), 
            other_preselect = ifelse(any(1 %in% other_preselect), 1, 0), 
            other_referendum = ifelse(any(1 %in% other_preselect), 1, 0))

psed_elec$election_promise <- rowSums(psed_elec %>% 
                                        ungroup() %>% 
                                        select(other_parlelect, 
                                               other_preselect, 
                                               other_referendum))

psed_elec <- psed_elec %>% 
  ungroup() %>% 
  rowwise() %>% 
  mutate(year = list(startyear:endyear)) %>% 
  unnest()

psed_elec <- psed_elec %>% 
  group_by(GWNo, location, year) %>% 
  summarise(election_promise = max(election_promise))

diss_df <- left_join(diss_df, 
                     psed_elec, 
                     by = c("GWNo", "year")) %>% 
  replace_na(list(election_promise = 0))


nelda_ps <- left_join(nelda_ps,
                      psed_elec, 
                      by = c("ccode" = "GWNo", "year")) %>% 
  replace_na(list(election_promise = 0))


# Estimate models
model_polity_elecpromise <- felm(polity2_t2 ~  
                                   cabinetINC * 
                                   aiddata_AidGDP_ln +
                                   log(GDP_per_capita) +
                                   ln_pop +
                                   conf_intens +
                                   nonstate + 
                                   WBnatres +
                                   polity2 +
                                   election_promise
                                 | year | 0 | GWNo,
                                 data=diss_df )

model_elecquality_elecpromise <- felm(v2xel_frefair ~ 
                                        aid_ln *  
                                        cabinetINC.12 +
                                        WBnatres + 
                                        fh + 
                                        nonstate + 
                                        conf_intens + 
                                        log(gdp_per_capita_un) + 
                                        log(population) +
                                        election_promise
                                      | year | 0 | country
                                      ,
                                      data = nelda_ps)


model_judind_elecpromise <- felm(LJI_t2 ~
                                   cabinetINC *
                                   aiddata_AidGDP_ln +
                                   ln_gdp_pc +
                                   ln_pop +
                                   conf_intens +
                                   nonstate + 
                                   WBnatres + 
                                   fh +
                                   election_promise
                                 | year | 0 | GWNo
                                 ,
                                 data = diss_df)


model_spending_elecpromise <- felm(v2dlencmps_t1 ~
                                     cabinetINC *  
                                     aiddata_AidGDP_ln +
                                     ln_gdp_pc +
                                     ln_pop +
                                     conf_intens +
                                     nonstate +
                                     WBnatres + 
                                     fh +
                                     election_promise
                                   | year | 0 | GWNo,
                                   data=diss_df)


# * Save Table 11 ---------------------------------------------------------


htmlreg(list(model_polity_elecpromise, 
             model_elecquality_elecpromise, 
             model_judind_elecpromise, 
             model_spending_elecpromise), 
        stars = c(0.01, 0.05, 0.1),
        custom.coef.map = coef_name_map,
        file = "./tables/appendix_table_11.html", 
        include.lr = F, 
        table = F,
        use.packages = F,
        include.rsquared = F, 
        include.variance = F)
