
# Libraries ---------------------------------------------------------------

library(lfe)
library(texreg)
library(tidyverse)
library(rms)
library(ggrepel)
library(gridExtra)

# Load Data ---------------------------------------------------------------

load("./data/diss_df.rda")


# Table 1 -----------------------------------------------------------------



# * Democracy scores --------------------------------------------------------

model_polity_cabinc <- felm(polity2_t2 ~  
                             cabinetINC * 
                             aiddata_AidGDP_ln +
                             log(GDP_per_capita) +
                             ln_pop +
                             conf_intens +
                             nonstate + 
                             WBnatres +
                             polity2 
                            | year | 0 | GWNo,
                           data=diss_df )


model_polity_cabcount <- felm(polity2_t2 ~  
                              cabinetCOUNT * 
                              aiddata_AidGDP_ln +
                              log(GDP_per_capita) +
                              ln_pop +
                              conf_intens +
                              nonstate + 
                              WBnatres +
                              polity2 
                            | year | 0 | GWNo,
                            data=diss_df)




# * Elections ---------------------------------------------------------------

load("./data/nelda_ps.rda")

model_aidps_quality_cabinc <- felm(v2xel_frefair ~ 
                                    aid_ln *  
                                    cabinetINC.12 +
                                    WBnatres + 
                                    fh + 
                                    nonstate + 
                                    conf_intens + 
                                    log(gdp_per_capita_un) + 
                                    log(population)
                                  | year | 0 | country
                                  ,
                                  data = nelda_ps)


model_aidps_quality_cabcount <- felm(v2xel_frefair ~ 
                                     aid_ln *  
                                     cabinetCOUNT.12 +
                                     WBnatres + 
                                     fh + 
                                     nonstate + 
                                     conf_intens + 
                                     log(gdp_per_capita_un) + 
                                     log(population)
                                   | year | 0 | country
                                   ,
                                   data = nelda_ps)



# * Judicial Independence ---------------------------------------------------


model_aidps_judind_LJI_cabinc<- felm(LJI_t2 ~
                                      cabinetINC *
                                      aiddata_AidGDP_ln +
                                      ln_gdp_pc +
                                      ln_pop +
                                      conf_intens +
                                      nonstate + 
                                      WBnatres + 
                                      fh
                                    | year | 0 | GWNo
                                    ,
                                    data = diss_df)



model_aidps_judind_LJI_cabcount <- felm(LJI_t2 ~
                                       cabinetCOUNT *
                                       aiddata_AidGDP_ln +
                                       ln_gdp_pc +
                                       ln_pop +
                                       conf_intens +
                                       nonstate + 
                                       WBnatres + 
                                       fh
                                     | year | 0 | GWNo
                                     ,
                                     data = diss_df)




# * Particularistic Spending ------------------------------------------------

model_aidps_spending_cabINC <- felm(v2dlencmps_t1 ~
                                     cabinetINC *  
                                     aiddata_AidGDP_ln +
                                     ln_gdp_pc +
                                     ln_pop +
                                     conf_intens +
                                     nonstate +
                                     WBnatres + 
                                     fh
                                   | year | 0 | GWNo,
                                   data=diss_df)


model_aidps_spending_cabCOUNT <- felm(v2dlencmps_t1 ~
                                      cabinetCOUNT *  
                                      aiddata_AidGDP_ln +
                                      ln_gdp_pc +
                                      ln_pop +
                                      conf_intens +
                                      nonstate +
                                      WBnatres + 
                                      fh
                                    | year | 0 | GWNo,
                                    data=diss_df)


# * Save Table 1 ------------------------------------------------------------

model_list <- list(model_polity_cabinc,
                   model_polity_cabcount,
                   model_aidps_quality_cabinc,
                   model_aidps_quality_cabcount,
                   model_aidps_judind_LJI_cabinc,
                   model_aidps_judind_LJI_cabcount,
                   model_aidps_spending_cabINC,
                   model_aidps_spending_cabCOUNT)


coef_name_map <- list(
  # PS vars
  cabinetINC = "Power-Sharing (binary)",
  cabinetINC.12 = "Power-Sharing (binary)",
  cabinetCOUNT = "Power-Sharing (No. of seats)", 
  cabinetCOUNT.12 = "Power-Sharing (No. of seats)",
  
  # aid vars
  dga_gdp_zero = "DGA/GDP (log)", 
  program_aid_gdp_zero = "Program Aid/GDP (log)", 
  commodity_aid_gdp_zero = "Budget Aid/GDP (log)", 
  aiddata_AidGDP_ln = "Aid / GDP (log)",
  aid_ln = "Aid / GDP (log)",
  
  # interaction terms
  "aid_ln:cabinetINC.12" = "Power-Sharing (binary) * Aid",
  "cabinetINC * aiddata_AidGDP_ln" = "Power-Sharing (binary) * Aid",
  "cabinetINC:aiddata_AidGDP_ln" = "Power-Sharing (binary) * Aid",
  "cabinetCOUNT * aiddata_AidGDP_ln" = "Power-Sharing (No. of seats) * Aid", 
  "cabinetCOUNT:aiddata_AidGDP_ln" = "Power-Sharing (No. of seats) * Aid",
  "aid_ln:cabinetCOUNT.12" = "Power-Sharing (No. of seats) * Aid",
  
  # control vars
  # ps_share = "PS (cabinet share)",
  # "ps_share * aiddata_AidGDP_ln" = "PS (cabinet share) * Aid",
  "log(GDP_per_capita)" = "GDP p/c (log)",
  ln_gdp_pc = "GDP p/c (log)",
  "log(gdp_per_capita_un)" = "GDP p/c (log)", 
  "log(population)" = "Population (log)",
  ln_pop = "Population (log)",
  conf_intens = "Conflict Intensity",
  nonstate = "Non-State Violence",
  WBnatres = "Nat. Res. Rents",
  polity2 = "Regime Type",
  fh = "Regime Type",
  Ethnic = "Ethnic Frac.",
  DS_ordinal = "UN PKO")


htmlreg(model_list, 
        stars = c(0.01, 0.05, 0.1),
        custom.coef.map = coef_name_map,
        file = "./tables/table_1.html", 
        groups = list("Constituent Terms" = 1:3, 
                      "Interaction Term" = 4:5, 
                      "Controls" = 6:11),
        include.lr = F, 
        table = F,
        use.packages = F,
        include.rsquared = F, 
        include.variance = F)


# Figure 1 ----------------------------------------------------------------


# * Data distribution -----------------------------------------------------



# to predict substantive effects from this model, we need to define data 
# distribution
diss_df$conflictID <- NULL
diss_df$year_fct <- as.factor(diss_df$year)
datadist_diss_df <- datadist(diss_df); options(datadist='datadist_diss_df')

# replicate Model from above Polity DV + cabINC
model_polity_cabinc <- ols(polity2_t2 ~  
                               cabinetINC * 
                               aiddata_AidGDP_ln +
                               ln_gdp_pc +
                               ln_pop +
                               conf_intens +
                               nonstate + 
                               WBnatres +
                               polity2 + year_fct,
                             data=diss_df, x=T, y=T)
model_polity_cabinc <- robcov(model_polity_cabinc, diss_df$GWNo)

# * Predictions -----------------------------------------------------------


# Calculate predictions for aid
prediction_democ_aid <- Predict(model_polity_cabinc, 
                                cabinetINC = c(0, 1), # no / much power-sharing
                                aiddata_AidGDP_ln = seq(-5.7, 5.17, 0.1),# range of aid
                                polity2 = 3,
                                year_fct = "2000",
                                # conf_intens = 1,
                                conf.int = 0.9) 


# * Plot ------------------------------------------------------------------



# left panel
subs_effects_pchng_aid <- ggplot(data.frame(prediction_democ_aid), 
                                 aes(x = exp(aiddata_AidGDP_ln), 
                                     y = yhat, 
                                     group = as.factor(cabinetINC))) + 
  geom_line( color = "black", size = 0.7) + 
  geom_ribbon(aes(ymax = upper, 
                  ymin = lower, 
                  fill = as.factor(cabinetINC)), 
              alpha = 0.7) +
  scale_fill_manual(values = c("#b3cde3", "#e41a1c"), 
                    labels = c("no", "yes"),
                    name = "Power-Sharing:") +
  geom_rug(data = diss_df, aes(x = exp(aiddata_AidGDP_ln)), inherit.aes = F) +
  
  theme_classic() +
  theme(text = element_text(size=8)) +
  labs(x = "Aid / GDP\n", 
       y = "Predicted Polity Scores") +
  theme(legend.position = "bottom") 

# Predictions power-sharing
prediction_democ_ps <- Predict(model_polity_cabinc, 
                               cabinetINC = seq(0, 1, 1), 
                               aiddata_AidGDP_ln = c(0, 3.4),
                               polity2 = 3,
                               year_fct = "2000",
                               # conf_intens = 1,
                               conf.int = 0.9)

prediction_democ_ps$aiddata_AidGDP_ln <- round(exp(prediction_democ_ps$aiddata_AidGDP_ln))


# data.frame for country reference
cntry_df <- data.frame(country = c("Nepal (2008)", "Haiti (2005)"), 
                       polity2 = c(6, 3), 
                       cabinetINC = c(1, 1))

# right panel
subs_effects_pchng_ps <- ggplot(data.frame(prediction_democ_ps), 
                                aes(x = as.factor(cabinetINC), 
                                    y = yhat, 
                                    group = as.factor(aiddata_AidGDP_ln))) + 
  geom_point( aes(color = as.factor(aiddata_AidGDP_ln)), size = 1,
              position = position_dodge(width = 0.5)) + 
  geom_errorbar(aes(ymax = upper, 
                    ymin = lower, 
                    color = as.factor(aiddata_AidGDP_ln)), 
                alpha = 0.7, 
                width = 0, 
                position = position_dodge(width = 0.5)) +
  geom_point(data = cntry_df, aes(x = as.factor(cabinetINC),
                                  y = polity2), inherit.aes = F) +
  geom_label_repel(data = cntry_df %>% filter(country == "Nepal (2008)"), 
                   aes(x = as.factor(cabinetINC),
                       y = polity2, label = country),
                   nudge_x = -0.4, 
                   inherit.aes = F,
                   size = 1.3,
                   segment.size = 0.25) +
  geom_label_repel(data = cntry_df %>% filter(country != "Nepal (2008)"), 
                   aes(x = as.factor(cabinetINC),
                       y = polity2, label = country),
                   nudge_x = 0.4, 
                   inherit.aes = F,
                   size = 1.3,
                   segment.size = 0.25) +
  scale_color_manual(values = c("#b3cde3", "#e41a1c"), 
                     name = "Aid in per cent of GDP:") +
  theme_classic() +
  scale_x_discrete(labels = c("no", "yes")) +
  theme(text = element_text(size=8)) +
  labs(x = "Power-Sharing\nGovernment", 
       y = "Predicted Polity Scores") +
  theme(legend.position = "bottom")


# output prediction plots

# * Save Figure 1 ------------------------------------------------------------


ggsave(file = "./plots/figure_1.pdf", 
       height = 6.5, width = 10, 
       plot = grid.arrange(subs_effects_pchng_ps,subs_effects_pchng_aid, 
                           nrow = 1), 
       scale = 0.5)



# Figure 2 ----------------------------------------------------------------


# * Election Predictions ----------------------------------------------------


# Year FE
nelda_ps$year_fct <- as.factor(nelda_ps$year)

# Estimate Model
datadist_nelda <- datadist(nelda_ps); options(datadist='datadist_nelda')
model_aidps_quality_cabinc <- ols(v2xel_frefair ~ 
                                      aid_ln *  
                                      cabinetINC.12 +
                                      WBnatres + 
                                      fh + 
                                      nonstate + 
                                      conf_intens +
                                      log(gdp_per_capita_un) + 
                                      log(population) +
                                      year_fct
                                    
                                    ,
                                    data = nelda_ps, x = T, y = T)
model_aidps_quality_cabinc <- robcov(model_aidps_quality_cabinc, nelda_ps$country)


prediction_nelda_ps <- Predict(model_aidps_quality_cabinc, 
                               cabinetINC.12 = seq(0, 1, 1), 
                               conf_intens = 1,
                               aid_ln = c(0, 3.4))

prediction_nelda_ps <- prediction_nelda_ps %>% 
  select(yhat, lower, upper, cabinetINC.12, aid_ln) %>% 
  rename(cabinetINC = cabinetINC.12, 
         aiddata_AidGDP_ln = aid_ln)

prediction_nelda_ps$dv <- "Elections"


# * Rule of Law Predictions -------------------------------------------------


# Estimate Model
diss_df$conflictID <- NULL # conflictID throws an error b/c of missing data
diss_df$year_fct <- factor(diss_df$year)
d <- datadist(diss_df); options(datadist='d')

model_aidps_judind_LJI_cabinc <- ols(LJI_t2 ~
                                         cabinetINC *
                                         aiddata_AidGDP_ln +
                                         ln_gdp_pc +
                                         ln_pop +
                                         conf_intens +
                                         nonstate + 
                                         WBnatres + 
                                         fh + year_fct
                                       ,
                                       data = diss_df, 
                                       x = T, y = T)
model_aidps_judind_LJI_cabinc <- robcov(model_aidps_judind_LJI_cabinc, diss_df$GWNo)

# generate predictions at different power-sharing levels
predictions_rol <- Predict(model_aidps_judind_LJI_cabinc, 
                           aiddata_AidGDP_ln = c(0, 3.4), # 0 = 1% Aid / GDP , 3.4 = 30%
                           cabinetINC = seq(0, 1, 1), 
                           conf.int = 0.9) # 90 % confidence intervals

predictions_rol$dv <- "Rule of Law"


# * Public Goods Predictions ------------------------------------------------


model_aidps_spending <- ols(v2dlencmps_t1 ~
                              cabinetINC *  
                              aiddata_AidGDP_ln +
                              ln_gdp_pc +
                              ln_pop +
                              conf_intens +
                              nonstate +
                              WBnatres + 
                              fh + year_fct,
                            data=diss_df, x=T, y=T)
model_aidps_spending <- rms::robcov(model_aidps_spending, diss_df$GWNo)


predictions_pubgoods <- Predict(model_aidps_spending, 
                                aiddata_AidGDP_ln = c(0, 3.4), # 0 = 1% Aid / GDP , 3.4 = 30%
                                cabinetINC = seq(0, 1, 1), 
                                conf.int = 0.9) # 90 % confidence intervals

predictions_pubgoods$dv <- "Public Goods"



# * Combine Predictions ------------------------------------------------

all_predictions <- prediction_nelda_ps %>% 
  data.frame() %>% 
  bind_rows(., predictions_rol %>%  
              select(yhat, lower, upper, cabinetINC, aiddata_AidGDP_ln, dv)) %>% 
  bind_rows(., predictions_pubgoods %>%  
              select(yhat, lower, upper, cabinetINC, aiddata_AidGDP_ln, dv)) %>% 
  mutate(dv = forcats::fct_relevel(dv, c("Elections", "Rule of Law", "Public Goods")))



# * Generate Plot ---------------------------------------------------------



plot_all_predictions <- ggplot(data.frame(all_predictions), 
                               aes(x = as.factor(cabinetINC), 
                                   y = yhat, 
                                   group = as.factor(aiddata_AidGDP_ln))) + 
  geom_point( aes(color = as.factor(aiddata_AidGDP_ln)), size = 1,
              position = position_dodge(width = 0.5)) + 
  geom_errorbar(aes(ymax = upper, 
                    ymin = lower, 
                    color = as.factor(aiddata_AidGDP_ln)), 
                alpha = 0.7, 
                width = 0, 
                position = position_dodge(width = 0.5)) +
  scale_color_manual(values = c("#b3cde3", "#e41a1c"), 
                     name = "Aid in per cent of GDP:", labels = c(1, 30)) +
  theme_bw() +
  scale_x_discrete(labels = c("no", "yes")) +
  labs(x = "Power-Sharing", 
       y = "") +
  facet_wrap( ~ dv, scales = "free") + 
  theme(legend.position = "bottom") +
  theme(strip.background = element_rect(fill = "lightgrey")) +
  theme(text = element_text(size=8), 
        panel.grid = element_blank()) 


# * Save Figure 2 ----------------------------------------------------------

ggsave(file = "./plots/figure_2.pdf", 
       height = 5, width = 10, 
       plot = plot_all_predictions,
       scale = 0.5)


